#!/bin/bash
#
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# dernières révisions       : 5/01/2009
#
#package			: gip
#homepage			: http://code.google.com/p/gip/
#source location	: http://dl.debain.org/gip/gip-1.7.0-1.tar.gz
#dependency         : gtkmm,GTK

softname='gip'
softversion='1.7.0_1'
softversionsrc='1.7.0-1'
packageversion='54.1'

#
# ZenWalk standard: type CPUet architecture
#
# arch='i486' -> le compileur utilise seulement les instructions 80486
# cpu='i686'  -> optimisation faîte pour PII et >
#
arch='i486'
cpu='i686'

#
# destination du package
#
prefix=/usr

#
# log
#
(

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "gros" PC: 6 compilations à la fois
#
# numjobs='-j6'
#
# "léger" PC: 2 compilations à la fois
#
numjobs='-j2'

#
# paramètres pour compiler
#
buildir=$(pwd)
src="$buildir/$softname-$softversionsrc"
srcpkg="$buildir/$softname-$softversionsrc.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://dl.debain.org/$softname/$softname-$softversionsrc.tar.gz

#
# preparer le répertoire qui accueillera la compilation
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

#
# mettre le slack-desc en place. 
#
cat <<EOF > $dest/install/slack-desc 
   |-----handy-ruler------------------------------------------------------|
gip: gip - GNOME GUI for making IP address based calculations
gip:
gip: For example, it can display IP addresses in binary format. 
gip: It is also possible to calculate subnets.
gip:
gip:
gip:
gip:
gip:
gip:
gip:
EOF



#
# Verifie si package est present
#
if [ -f $softname-$softversionsrc.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
tar xzvf $srcpkg
cd $src	

#
# "faire" le package package
#
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

sed -i 's|-DHAVE_CONFIG_H|$CFLAGS -DHAVE_CONFIG_H|g' build.sh

./build.sh --install --prefix $dest/usr

rm -rf $dest/usr/share/gnome

#
# "faire" .desktop
#
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[desktop Entry]
Encoding=UTF-8
Name=Gip IP Address Calculator
Name[de]=Gip IP-Adress-Rechner
GenericName=IP Adress Calculator
GenericName[de]=IP-Adress-Rechner
Comment=Calculate IP addresses and networks
Comment[de]=IP-Adressen und Netzbereiche berechnen
Exec=gip %U
StartupNotify=true
Terminal=false
Icon=calc
Type=Application
Categories=GNOME;GTK;Utility;
MimeType=application/x-gip;
EOF

cat << "EOF" > $dest/install/doinst.sh
# update the mime desktop database
if [ -x usr/bin/update-desktop-database ]; then
     usr/bin/update-desktop-database -q
fi
# update the mime database
if [ -x usr/bin/update-mime-database ]; then
     usr/bin/update-mime-database usr/share/mime > /dev/null 2>&1
fi
EOF

# ajout des fichiers de docs, infos, ...
#
    cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING ChangeLog INSTALL README \
      $dest/usr/doc/$softname-$softversion
    rm -rf $dest/usr/doc/gip

#
# Stripper les éxécutables
# (Commenter ces lignes si besoin d'infos de débuggage)
#
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)
#
# Compresser les pages Man
#
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

#
# Mettre le zenbuild à sa place
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

#
# fixer les permissions
#
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#
# fabriquer le zenpackage
#
cd $dest
makepkg -l y -c n $dest.tgz

#
# produire la signature md5 du package
#
cd $buildir
md5sum $package.tgz > $package.md5

#
# produire le fichier .dep
#
cd $buildir
echo -e "atk,cairomm,cxxlibs,directfb,expat,fontconfig,freetype,gcc,glib2,\
glibmm,gtk+2,gtkmm,libpng,libsigc++,pango,xcb,xorg-libs,zlib" > $package.dep

#
# produire le fichier src
#
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/gip/source/build-gip.sh > $package.src
echo $source >> $package.src

#
# supprimer source
#
rm -rf $src
rm -rf $dest

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
